@@ -63,7 +63,8 @@ function _extractStylesheetImages($stylesheet) {
 }
 
 function list_dir($dir, $path='') {
-    global $gCms, $config;
+    $gCms = cmsms();
+		$config = $gCms->GetConfig();
     $listDir = array();
     if ($handler = opendir($dir)) {
         while (($sub = readdir($handler)) !== FALSE) {
@@ -280,12 +281,11 @@ switch ($step) {
         }
         # write items to session
         $_SESSION['tms']['found_pages'] = $found_pages;
-
+				
         # prepare table for this step
         $all_modules = array();
-        foreach ($gCms->modules as $module_name => $details) {
-            $all_modules[] = $module_name;
-        }
+				$modops = $gCms->GetModuleOperations();
+				$all_modules = $modops->GetInstalledModules();
         $tmp = array();
         $i = 1;
         foreach ($all_modules as $module_name) {
@@ -310,7 +310,7 @@ switch ($step) {
         $found_templates = $_SESSION['tms']['found_templates'];
         $found_styles = $_SESSION['tms']['found_styles'];
         $found_pages = $_SESSION['tms']['found_pages'];
-
+				
         # get selected items from the previous step
         # get module templates
         foreach ($params as $key => $value) {
@@ -325,7 +325,7 @@ switch ($step) {
         }
         # write items to session
         $_SESSION['tms']['found_modules'] = $found_modules;
-
+				
         # prepare table for this step
         $blockops = & $gCms->GetGlobalContentOperations();
         $all_gbls = $blockops->LoadHtmlBlobs();
@@ -454,9 +454,8 @@ switch ($step) {
 
         # prepare table for this step
         $all_modules = array();
-        foreach ($gCms->modules as $module_name => $details) {
-            $all_modules[] = $module_name;
-        }
+				$modops = $gCms->GetModuleOperations();
+				$all_modules = $modops->GetInstalledModules();
         $tmp = array();
         $i = 1;
         foreach ($all_modules as $module_name) {
@@ -484,7 +483,7 @@ switch ($step) {
         $found_blocks = $_SESSION['tms']['found_blocks'];
         $found_udts = $_SESSION['tms']['found_udts'];
         $found_files = $_SESSION['tms']['found_files'];
-
+				
         # get selected items from the previous step
         $tmp = array();
         foreach ($params as $key => $value) {
@@ -762,7 +761,7 @@ switch ($step) {
 
             $module_templates = $doc->createElement('module_templates');
             $package->appendChild($module_templates);
-
+						
             foreach ($found_modules as $found_module) {
                 $module_template = $doc->createElement('module_template');
                 $module_templates->appendChild($module_template);
@@ -829,7 +828,7 @@ switch ($step) {
                 $child->appendChild($value);
                 $child = $doc->createElement('code');
                 $userplugin->appendChild($child);
-                $value = $doc->createCDATASection($code);
+                $value = $doc->createCDATASection($code['code']);
                 $child->appendChild($value);
             }
         }
