@@ -61,14 +61,16 @@ function xml_parse_into_assoc($file) {
 }
 
 function getTemplateIdByName($name) {
-    global $db;
+    $gCms = cmsms();
+		$db = $gCms->GetDb();
     $query = "SELECT template_id FROM " . cms_db_prefix() . "templates WHERE template_name = ?";
     $result = $db->getOne($query, array($name));
     return $result;
 }
 
 function insertImport($theme_id, $type, $name, $system_id = '', $module = '', $location = '') {
-    global $db;
+    $gCms = cmsms();
+		$db = $gCms->GetDb();
     $insert = false;
     switch ($type) {
         case 'template':
@@ -148,7 +150,7 @@ function saveEncodedFile($obj, $prefix, $name, $location, $encoded, $data) {
     }
 
     // and put it out there
-    global $gCms;
+    $gCms = cmsms();
     $fn = $prefix . DIRECTORY_SEPARATOR . $newloc;
     $fp = fopen($fn, "w");
     if (!$fp) {
@@ -160,7 +162,8 @@ function saveEncodedFile($obj, $prefix, $name, $location, $encoded, $data) {
 }
 
 function checkPage($page_hierarchy, $found_pages) {
-    global $db, $gCms;
+    $gCms = cmsms();
+		$db = $gCms->GetDb();
     $paths = array();
     $parents = array();
     foreach ($found_pages as $page) {
@@ -600,6 +603,9 @@ switch ($step) {
         $this->smarty->assign('submit', '');
 
         break;
+		case 5:
+				$this->Redirect($id, 'defaultadmin', $returnid);
+				break;
 }
 
 
